@@ -1,5 +1,5 @@
 package Clipboard;
-$Clipboard::VERSION = '0.24';
+$Clipboard::VERSION = '0.25';
 use strict;
 use warnings;
 
@@ -72,7 +72,7 @@ Clipboard - Copy and paste with any OS
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -192,9 +192,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/clipboard>
+L<https://github.com/shlomif/Clipboard>
 
-  git clone https://github.com/shlomif/Clipboard
+  git clone git://github.com/shlomif/Clipboard.git
 
 =head1 AUTHOR
 
@@ -203,7 +203,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/clipboard/issues>
+L<https://github.com/shlomif/Clipboard/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
